@@ -113,6 +113,7 @@ typedef struct device_desc device_description;
 */
 int check_device_by_ximc_information (const char* name, device_information_t* info, uint32_t* serial, controller_name_t* cname, stage_name_t* sname)
 {
+	/* ACHTUNG!!! WE add a kludge to support STELM Manufacturer, #96430. Later it must be fixed! */
 	device_t device;
 	device_information_t info_local;
 	device_information_t* pinfo = info ? info : &info_local;
@@ -134,7 +135,8 @@ int check_device_by_ximc_information (const char* name, device_information_t* in
 		if (get_device_information_impl_unsynced( device, pinfo ) == result_ok)
 		{
 			log_debug( L"enum thread: successfully got GETI" );
-            if (!strcmp(pinfo->Manufacturer, "XIMC") || !strcmp(pinfo->Manufacturer, "EPC "))
+			// ACHTUNG! The kludge! "!strcmp(pinfo->Manufacturer, "STLM")" must be removed later. #96430
+			if (!strcmp(pinfo->Manufacturer, "XIMC") || !strcmp(pinfo->Manufacturer, "EPC ") || !strcmp(pinfo->Manufacturer, "STLM"))
 			{
 				is_ximc_device = 1;
 				if (serial)
